@@ -79,7 +79,7 @@ def get_code(token_type):
 
 class SpellCheckPlugin:
     name = "flake8-spellcheck"
-    version = "0.12.0"
+    version = "0.13.0"
 
     def __init__(self, tree, filename="(none)", file_tokens=None):
         self.file_tokens = file_tokens
@@ -119,22 +119,25 @@ class SpellCheckPlugin:
             # need to use a command separated list to work round it
             help="Command separated list of dictionaries to enable",
             default="en_US,python,technical",
+            comma_separated_list=True,
             parse_from_config=True,
         )
 
     @classmethod
     def parse_options(cls, options):
         cls.whitelist_path = options.whitelist
-        cls.dictionaries = [d + ".txt" for d in options.dictionaries.split(",")]
+        cls.dictionaries = [d + ".txt" for d in options.dictionaries]
 
     def _detect_errors(self, tokens, use_symbols, token_type):
         code = get_code(token_type)
 
         for position, token in tokens:
+            test_token = token.lower().strip("'").strip('"')
+
             if use_symbols:
-                valid = token.lower() in self.words
+                valid = test_token in self.words
             else:
-                valid = token.lower() in self.no_symbols
+                valid = test_token in self.no_symbols
 
             # Need a way of matching words without symbols
             if not valid and not is_number(token):
